# About

{Obj} was built with **DetaMVC**   
The fastest way to get to production!

**Learn More**:  

- [MKDocs-Material](https://squidfunk.github.io/mkdocs-material/)
- [Markdown Basics](https://www.markdownguide.org/cheat-sheet/)
- [DetaMVC Documentation](https://detamvc.deta.dev)